
package signalValues;

import javax.persistence.Basic;
import javax.persistence.Embeddable;

@Embeddable
public class SignalValueImpl {

	@Basic
	protected boolean defined;

	@Basic
	String originalValue;

	/**
	 * Constructs a new instance whose value is currently undefined.
	 */
	public SignalValueImpl() {
		defined = false;
	}

	/**
	 * Clear the content of the originalString.
	 * 
	 * <p>
	 * The OriginalValue must be cleared if the value has been changed. That can
	 * be done by this method.
	 * </p>
	 */
	protected void clearOriginalValue() {
		originalValue = null;
	}

	public boolean isDefined() {
		return defined;
	}

	public void setDefined(boolean defined) {
		if (!defined) {
			clearOriginalValue();
		}
		this.defined = defined;
	}

	public boolean existOriginalString() {
		return (originalValue != null);
	}

	public String getOriginalString() {
		if (originalValue != null) {
			return originalValue;
		} else {
			return getSignalValueAsString();
		}
	}

	public String getSignalValueAsString() {
		if (!defined) {
			if (originalValue != null) {
				return originalValue;
			}
			return "*";
		} else {
			throw new IllegalArgumentException();
		}
	}

	@Override
	public String toString() {
		try {
			return getSignalValueAsString();
		} catch (Exception e) {
			return "";
		}
	}

}
